@@ -8,7 +8,7 @@
 """
 Deprecated module that used to contain SelectReactor and PosixReactorBase
 
-Maintainer: U{Itamar Shtull-Trauring<mailto:twisted@itamarst.org>}
+Maintainer: Itamar Shtull-Trauring
 """
 
 import warnings
