@@ -6,7 +6,7 @@
 """
 Support for results that aren't immediately available.
 
-Maintainer: U{Glyph Lefkowitz<mailto:glyph@twistedmatrix.com>}
+Maintainer: Glyph Lefkowitz
 """
 
 from __future__ import nested_scopes, generators
@@ -48,24 +48,25 @@ def succeed(result):
     d.callback(result)
     return d
 
-class _nothing: pass
 
-def fail(result=_nothing):
+def fail(result=None):
     """
     Return a Deferred that has already had '.errback(result)' called.
 
     See L{succeed}'s docstring for rationale.
 
-    @param result: The same argument that L{Deferred.errback<twisted.internet.defer.Deferred.errback>} takes.
+    @param result: The same argument that L{Deferred.errback} takes.
+
+    @raise NoCurrentExceptionError: If C{result} is C{None} but there is no
+        current exception state.
 
     @rtype: L{Deferred}
     """
-    if result is _nothing:
-        result = failure.Failure()
     d = Deferred()
     d.errback(result)
     return d
 
+
 def execute(callable, *args, **kw):
     """Create a deferred from a callable and arguments.
 
@@ -243,7 +244,8 @@ class Deferred:
 
 
     def errback(self, fail=None):
-        """Run all error callbacks that have been added to this Deferred.
+        """
+        Run all error callbacks that have been added to this Deferred.
 
         Each callback will have its result passed as the first
         argument to the next; this way, the callbacks act as a
@@ -257,6 +259,9 @@ class Deferred:
 
         Passing a string as `fail' is deprecated, and will be punished with
         a warning message.
+
+        @raise NoCurrentExceptionError: If C{fail} is C{None} but there is
+            no current exception state.
         """
         if not isinstance(fail, failure.Failure):
             fail = failure.Failure(fail)
@@ -409,42 +414,58 @@ class DebugInfo:
                 log.msg("(debug: " + debugInfo + ")", isError=True)
             log.err(self.failResult)
 
-class FirstError(Exception):
-    """First error to occur in a DeferredList if fireOnOneErrback is set.
 
-    @ivar subFailure: the L{Failure} that occurred.
-    @ivar index: the index of the Deferred in the DeferredList where it
-    happened.
+
+class FirstError(Exception):
+    """
+    First error to occur in a L{DeferredList} if C{fireOnOneErrback} is set.
+
+    @ivar subFailure: The L{Failure} that occurred.
+    @type subFailure: L{Failure}
+
+    @ivar index: The index of the L{Deferred} in the L{DeferredList} where
+        it happened.
+    @type index: C{int}
     """
     def __init__(self, failure, index):
+        Exception.__init__(self, failure, index)
         self.subFailure = failure
         self.index = index
 
+
     def __repr__(self):
-        return 'FirstError(%r, %d)' % (self.subFailure, self.index)
+        """
+        The I{repr} of L{FirstError} instances includes the repr of the
+        wrapped failure's exception and the index of the L{FirstError}.
+        """
+        return 'FirstError[#%d, %r]' % (self.index, self.subFailure.value)
+
 
     def __str__(self):
-        return repr(self)
+        """
+        The I{str} of L{FirstError} instances includes the I{str} of the
+        entire wrapped failure (including its traceback and exception) and
+        the index of the L{FirstError}.
+        """
+        return 'FirstError[#%d, %s]' % (self.index, self.subFailure)
 
-    def __getitem__(self, index):
-        warnings.warn("FirstError.__getitem__ is deprecated.  "
-                      "Use attributes instead.",
-                      category=DeprecationWarning, stacklevel=2)
-        return [self.subFailure, self.index][index]
 
-    def __getslice__(self, start, stop):
-        warnings.warn("FirstError.__getslice__ is deprecated.  "
-                      "Use attributes instead.",
-                      category=DeprecationWarning, stacklevel=2)
-        return [self.subFailure, self.index][start:stop]
+    def __cmp__(self, other):
+        """
+        Comparison between L{FirstError} and other L{FirstError} instances
+        is defined as the comparison of the index and sub-failure of each
+        instance.  L{FirstError} instances don't compare equal to anything
+        that isn't a L{FirstError} instance.
+
+        @since: 8.2
+        """
+        if isinstance(other, FirstError):
+            return cmp(
+                (self.index, self.subFailure),
+                (other.index, other.subFailure))
+        return -1
+
 
-    def __eq__(self, other):
-        if isinstance(other, tuple):
-            return tuple(self) == other
-        elif isinstance(other, FirstError):
-            return (self.subFailure == other.subFailure and
-                    self.index == other.index)
-        return False
 
 class DeferredList(Deferred):
     """I combine a group of deferreds into one callback.
@@ -623,8 +644,6 @@ def _deferGenerator(g, deferred):
 
 def deferredGenerator(f):
     """
-    Maintainer: U{Christopher Armstrong<mailto:radix@twistedmatrix.com>}
-
     deferredGenerator and waitForDeferred help you write Deferred-using code
     that looks like a regular sequential function. If your code has a minimum
     requirement of Python 2.5, consider the use of L{inlineCallbacks} instead,
@@ -773,8 +792,6 @@ def _inlineCallbacks(result, g, deferred):
 
 def inlineCallbacks(f):
     """
-    Maintainer: U{Christopher Armstrong<mailto:radix@twistedmatrix.com>}
-
     WARNING: this function will not work in Python 2.4 and earlier!
 
     inlineCallbacks helps you write Deferred-using code that looks like a
